@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2014 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -17,16 +17,16 @@
  * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_INPUT_H
-#define __WEECHAT_INPUT_H 1
+#ifndef WEECHAT_INPUT_H
+#define WEECHAT_INPUT_H 1
 
 struct t_gui_buffer;
 struct t_weechat_plugin;
 
-extern void input_exec_command (struct t_gui_buffer *buffer,
-                                int any_plugin,
-                                struct t_weechat_plugin *plugin,
-                                const char *string);
-extern void input_data (struct t_gui_buffer *buffer, const char *data);
+extern int input_exec_command (struct t_gui_buffer *buffer,
+                               int any_plugin,
+                               struct t_weechat_plugin *plugin,
+                               const char *string);
+extern int input_data (struct t_gui_buffer *buffer, const char *data);
 
-#endif /* __WEECHAT_INPUT_H */
+#endif /* WEECHAT_INPUT_H */
