@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -190,11 +190,14 @@ extern void gui_window_search_stop_here (struct t_gui_window *window);
 extern void gui_window_search_stop (struct t_gui_window *window);
 extern int gui_window_search_text (struct t_gui_window *window);
 extern void gui_window_zoom (struct t_gui_window *window);
-extern struct t_hdata *gui_window_hdata_window_cb (void *data,
+extern struct t_hdata *gui_window_hdata_window_cb (const void *pointer,
+                                                   void *data,
                                                    const char *hdata_name);
-extern struct t_hdata *gui_window_hdata_window_scroll_cb (void *data,
+extern struct t_hdata *gui_window_hdata_window_scroll_cb (const void *pointer,
+                                                          void *data,
                                                           const char *hdata_name);
-extern struct t_hdata *gui_window_hdata_window_tree_cb (void *data,
+extern struct t_hdata *gui_window_hdata_window_tree_cb (const void *pointer,
+                                                        void *data,
                                                         const char *hdata_name);
 extern int gui_window_add_to_infolist (struct t_infolist *infolist,
                                        struct t_gui_window *window);
