@@ -1,7 +1,7 @@
 /*
  * alias-command.c - alias commands
  *
- * Copyright (C) 2003-2016 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2017 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -286,8 +286,8 @@ alias_command_init ()
            "completion of /sajoin:\n"
            "    /alias addcompletion %%sajoin forcejoin /quote forcejoin"),
         "list %(alias)"
-        " || add %(alias) %(commands)|%(alias_value)"
-        " || addcompletion %- %(alias) %(commands)|%(alias_value)"
+        " || add %(alias) %(commands:/)|%(alias_value)"
+        " || addcompletion %- %(alias) %(commands:/)|%(alias_value)"
         " || del %(alias)|%*",
         &alias_command_cb, NULL, NULL);
 }
